@@ -18,12 +18,12 @@ _CONFIGS = {
     '文字通用':
         {'_attrs':
              [['text', 1, 'str'],
-              ['class', 1, 'str'],
-              ['kv', 1, 'str', ('other', 'key', 'value')],
-              ['type', 1, 'str', ('印刷体', '手写体', '其它')],
+              ['category', 1, 'str'],
+              ['text_kv', 1, 'str', ('other', 'key', 'value')],
+              ['text_type', 1, 'str', ('印刷体', '手写体', '其它')],
               ],
-         'label_line_color': ['class'],
-         'label_vertex_fill_color': ['kv']
+         'label_line_color': ['category'],
+         'label_vertex_fill_color': ['text_kv']
          },
     '核酸检测':
         {'_attrs':
@@ -37,12 +37,12 @@ _CONFIGS = {
     '三码合一入学判定':
         {'_attrs':
              [['text', 1, 'str'],
-              ["class", 1, "str", ("姓名", "身份证", "联系方式", "采样时间", "检测时间", "核酸结果",
-                                   "14天经过或途经", "健康码颜色", "其他类")],
-              ['kv', 1, 'str', ('key', 'value')],
+              ["category", 1, "str", ("姓名", "身份证", "联系方式", "采样时间", "检测时间", "核酸结果",
+                                      "14天经过或途经", "健康码颜色", "其他类")],
+              ['text_kv', 1, 'str', ('key', 'value')],
               ],
-         'label_shape_color': 'content_class'.split(','),
-         'default_label': json.dumps({'text': '', 'class': '其他类', 'kv': 'value'}, ensure_ascii=False),
+         'label_shape_color': 'category'.split(','),
+         'default_label': json.dumps({'text': '', 'category': '其他类', 'text_kv': 'value'}, ensure_ascii=False),
          },
     'XlCoco': {
         '_attrs':
